=======================
Test Problems Reference
=======================

.. hint::

    For instructions on how to contribute your own inversion test problem,
    check out our `contributor's guide <../../contributor_guide/new_contrib.html>`_

This page contains detailed documentation for all the Espresso problems, 
including their problem definition, authors' suggestions on inference and 
other metadata.


.. toctree::
    :maxdepth: 1
    
